pub struct RawStateEventWithKeys<T: AnyStateEventEnum> {
pub raw: Raw<T>,
pub event_type: StateEventType,
pub state_key: String,
/* private fields */
}Expand description
A raw state event and its (type, state_key) tuple that identifies it
in the state map of the room.
This type can also cache the deserialized event lazily when using
RawStateEventWithKeys::deserialize_as().
Fields
raw: Raw<T>The raw state event.
event_type: StateEventTypeThe type of the state event.
state_key: StringThe state key of the state event.
Implementations
Sourceimpl<T: AnyStateEventEnum> RawStateEventWithKeys<T>
impl<T: AnyStateEventEnum> RawStateEventWithKeys<T>
Sourcepub fn try_from_raw_state_event(raw: Raw<T>) -> Option<Self>
pub fn try_from_raw_state_event(raw: Raw<T>) -> Option<Self>
Try to construct a RawStateEventWithKeys from the given raw state
event.
Returns None if extracting the type or state_key fails.
Sourcepub fn deserialize(&mut self) -> Option<&T>
pub fn deserialize(&mut self) -> Option<&T>
Try to deserialize the raw event.
The result of the event deserialization is cached for future calls to this method.
Returns None if the deserialization failed.
Sourcepub fn deserialize_as_minimal_event<F, C>(
&mut self,
as_variant_fn: F,
) -> Option<MinimalStateEvent<C>>where
F: FnOnce(AnyPossiblyRedactedStateEventContent) -> Option<C>,
C: StaticEventContent + PossiblyRedactedStateEventContent + RedactContent,
pub fn deserialize_as_minimal_event<F, C>(
&mut self,
as_variant_fn: F,
) -> Option<MinimalStateEvent<C>>where
F: FnOnce(AnyPossiblyRedactedStateEventContent) -> Option<C>,
C: StaticEventContent + PossiblyRedactedStateEventContent + RedactContent,
Try to deserialize the raw event and return it as a
MinimalStateEvent using the selected variant of
AnyPossiblyRedactedStateEventContent.
This method should only be called if the variant is already known. It is
considered a developer error for as_variant_fn to return None, but
this API was chosen to simplify closures that use the
as_variant! macro.
The result of the event deserialization is cached for future calls to this method.
Returns None if the deserialization failed or if as_variant_fn
returns None.
Sourceimpl RawStateEventWithKeys<AnySyncStateEvent>
impl RawStateEventWithKeys<AnySyncStateEvent>
Sourcepub fn try_from_raw_timeline_event(
raw: &Raw<AnySyncTimelineEvent>,
) -> Option<Self>
pub fn try_from_raw_timeline_event( raw: &Raw<AnySyncTimelineEvent>, ) -> Option<Self>
Try to construct a RawStateEventWithKeys from the given raw
timeline event.
Returns None if deserializing the type or state_key fails, or if
the event is not a state event.
Sourcepub fn deserialize_as<F, C>(
&mut self,
as_variant_fn: F,
) -> Option<&SyncStateEvent<C>>where
F: FnOnce(&AnySyncStateEvent) -> Option<&SyncStateEvent<C>>,
C: StaticEventContent + StaticStateEventContent + RedactContent,
C::Redacted: RedactedStateEventContent,
pub fn deserialize_as<F, C>(
&mut self,
as_variant_fn: F,
) -> Option<&SyncStateEvent<C>>where
F: FnOnce(&AnySyncStateEvent) -> Option<&SyncStateEvent<C>>,
C: StaticEventContent + StaticStateEventContent + RedactContent,
C::Redacted: RedactedStateEventContent,
Try to deserialize the raw event and return the selected variant of
AnySyncStateEvent.
This method should only be called if the variant is already known. It is
considered a developer error for as_variant_fn to return None, but
this API was chosen to simplify closures that use the
as_variant! macro.
The result of the event deserialization is cached for future calls to this method.
Returns None if the deserialization failed or if as_variant_fn
returns None.
Sourceimpl RawStateEventWithKeys<AnyStrippedStateEvent>
impl RawStateEventWithKeys<AnyStrippedStateEvent>
Sourcepub fn deserialize_as<F, C>(
&mut self,
as_variant_fn: F,
) -> Option<&StrippedStateEvent<C>>where
F: FnOnce(&AnyStrippedStateEvent) -> Option<&StrippedStateEvent<C>>,
C: StaticEventContent + PossiblyRedactedStateEventContent,
pub fn deserialize_as<F, C>(
&mut self,
as_variant_fn: F,
) -> Option<&StrippedStateEvent<C>>where
F: FnOnce(&AnyStrippedStateEvent) -> Option<&StrippedStateEvent<C>>,
C: StaticEventContent + PossiblyRedactedStateEventContent,
Try to deserialize the raw event and return the selected variant of
AnyStrippedStateEvent.
This method should only be called if the variant is already known. It is
considered a developer error for as_variant_fn to return None, but
this API was chosen to simplify closures that use the
as_variant! macro.
The result of the event deserialization is cached for future calls to this method.
Returns None if the deserialization failed or if as_variant_fn
returns None.