pub struct RequestedRequiredStates { /* private fields */ }Expand description
Represent the required_state values sent by a sync request.
This is useful to track what state events have been requested when handling a response.
For example, if a sync requests the m.room.encryption state event, and the
server replies with nothing, if means the room is not encrypted. Without
knowing which state event was required by the sync, it is impossible to
interpret the absence of state event from the server as the room’s
encryption state is not encrypted or the room’s encryption state is
unknown.
Implementations
Sourceimpl RequestedRequiredStates
impl RequestedRequiredStates