RoomMember

Struct RoomMember 

pub struct RoomMember { /* private fields */ }
A member of a room.

Implementations

Source

impl RoomMember

pub fn user_id(&self) -> &UserId

Get the unique user id of this member.

pub fn event(&self) -> &Arc<MemberEvent>

Get the original member event

pub fn display_name(&self) -> Option<&str>

Get the display name of the member if there is one.

pub fn name(&self) -> &str

Get the name of the member.

This returns either the display name or the local part of the user id if the member didn’t set a display name.

pub fn avatar_url(&self) -> Option<&MxcUri>

Get the avatar url of the member, if there is one.

pub fn status(&self) -> Option<&StatusProfileField>

Available on crate feature unstable-msc4426 only.

Get the user’s status, if any.

This is the user-set status (emoji + text) taken from the user’s global profile.

Global profiles are only populated when syncing via sliding sync with the profiles extension enabled; this is always None under sync v2.

pub fn call(&self) -> Option<&CallProfileField>

Available on crate feature unstable-msc4426 only.

Get the user’s call indicator, if any.

This indicates the user is currently in a call (and optionally how long they’ve been in it). It is taken from the user’s global profile.

Global profiles are only populated when syncing via sliding sync with the profiles extension enabled; this is always None under sync v2.

pub fn normalized_power_level(&self) -> UserPowerLevel

Get the normalized power level of this member.

The normalized power level depends on the maximum power level that can be found in a certain room, positive values that are not Infinite are always in the range of 0-100.

pub fn power_level(&self) -> UserPowerLevel

Get the power level of this member.

pub fn can_ban(&self) -> bool

Whether this user can ban other users based on the power levels.

Same as member.can_do(PowerLevelAction::Ban).

pub fn can_invite(&self) -> bool

Whether this user can invite other users based on the power levels.

Same as member.can_do(PowerLevelAction::Invite).

pub fn can_kick(&self) -> bool

Whether this user can kick other users based on the power levels.

Same as member.can_do(PowerLevelAction::Kick).

pub fn can_redact_own(&self) -> bool

Whether this user can redact their own events based on the power levels.

Same as member.can_do(PowerLevelAction::RedactOwn).

pub fn can_redact_other(&self) -> bool

Whether this user can redact events of other users based on the power levels.

Same as member.can_do(PowerLevelAction::RedactOther).

pub fn can_send_message(&self, msg_type: MessageLikeEventType) -> bool

Whether this user can send message events based on the power levels.

Same as member.can_do(PowerLevelAction::SendMessage(msg_type)).

pub fn can_send_state(&self, state_type: StateEventType) -> bool

Whether this user can send state events based on the power levels.

Same as member.can_do(PowerLevelAction::SendState(state_type)).

pub fn can_pin_or_unpin_event(&self) -> bool

Whether this user can pin or unpin events based on the power levels.

pub fn can_trigger_room_notification(&self) -> bool

Whether this user can notify everybody in the room by writing @room in a message.

Same as member. can_do(PowerLevelAction::TriggerNotification(NotificationPowerLevelType::Room)).

pub fn can_do(&self, action: PowerLevelAction) -> bool

Whether this user can do the given action based on the power levels.

pub fn name_ambiguous(&self) -> bool

Is the name that the member uses ambiguous in the room.

A name is considered to be ambiguous if at least one other member shares the same name.

pub fn membership(&self) -> &MembershipState

Get the membership state of this member.

pub fn is_ignored(&self) -> bool

Is the room member ignored by the current account user

pub fn is_service_member(&self) -> bool

Is the room member a service member.